# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
from .models_predictions import ModelsPredictions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class InferencePrediction(UniversalBaseModel):
    file: str = pydantic.Field()
    """
    A file path relative to the top level source URL or file.
    """

    models: ModelsPredictions

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .posted_webhook_event_type import PostedWebhookEventType
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PostedWebhookSpec(UniversalBaseModel):
    """
    URL and settings for a specific webhook to be posted to the server
    """

    url: str = pydantic.Field()
    """
    URL to send the webhook to
    """

    events: typing.List[PostedWebhookEventType] = pydantic.Field()
    """
    Events this URL is subscribed to
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .validation_error_loc_item import ValidationErrorLocItem
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ValidationError(UniversalBaseModel):
    loc: typing.List[ValidationErrorLocItem]
    msg: str
    type: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PostedEventMessageSpec(UniversalBaseModel):
    """
    Settings for a specific event_message to be posted to the server
    """

    enabled: bool = pydantic.Field()
    """
    Boolean indicating if this event message is enabled.
    
    If set to `true`, a message will be sent when the circumstances for the specific event are met.
    """

    text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text to use as the event message when the corresponding event occurs. If no text is specified, EVI will generate an appropriate message based on its current context and the system prompt.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SentimentScore(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Level of sentiment, ranging from `1` (negative) to `9` (positive)
    """

    score: float = pydantic.Field()
    """
    Prediction for this level of sentiment
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
